@@ -14,20 +14,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""
+GPX related stuff
+"""
+
 import pdb
 
 import logging as mod_logging
 import math as mod_math
-import datetime as mod_datetime
 import collections as mod_collections
-
-import utils as mod_utils
 import copy as mod_copy
-import geo as mod_geo
 
-"""
-GPX related stuff
-"""
+from . import utils as mod_utils
+from . import geo as mod_geo
 
 # GPX date format
 DATE_FORMAT = '%Y-%m-%dT%H:%M:%SZ'
@@ -63,9 +62,7 @@ PointData = mod_collections.namedtuple(
         ('point', 'distance_from_start', 'track_no', 'segment_no', 'point_no'))
 
 class GPXException(Exception):
-
-    def __init__(self, message):
-        Exception.__init__(self, message)
+    pass
 
 class GPXWaypoint(mod_geo.Location):
 	
@@ -252,7 +249,7 @@ class GPXRoutePoint(mod_geo.Location):
 
     def to_xml(self, version=None):
         content = ''
-        if self.elevation != None:
+        if self.elevation is not None:
             content += mod_utils.to_xml('ele', content=self.elevation)
         if self.time:
             content += mod_utils.to_xml('time', content=self.time.strftime(DATE_FORMAT))
@@ -1292,17 +1289,22 @@ class GPX:
 
         return MovingData(moving_time, stopped_time, moving_distance, stopped_distance, max_speed)
 
-    def reduce_points(self, max_points_no, min_distance=None):
+    def reduce_points(self, max_points_no=None, min_distance=None):
         """
         Reduce this track to the desired number of points
         max_points = The maximum number of points after the reduction
         min_distance = The minimum distance between two points
         """
 
-        if not min_distance:
-            points_no = len(list(self.walk()))
-            if not max_points_no or points_no <= max_points_no:
-                return
+        if max_points_no is None and min_distance is None:
+            raise ValueError("Either max_point_no or min_distance must be supplied")
+
+        if max_points_no is not None and max_points_no < 2:
+            raise ValueError("max_points_no must be greater than or equal to 2")
+
+        points_no = len(list(self.walk()))
+        if max_points_no is not None and points_no <= max_points_no:
+            return
 
         length = self.length_3d()
 
