@@ -14,8 +14,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from __future__ import print_function
+
 import pdb
 
+import re as mod_re
 import logging as mod_logging
 import datetime as mod_datetime
 import xml.dom.minidom as mod_minidom
@@ -25,13 +28,12 @@ try:
 except:
     pass # LXML not available
 
-import gpx as mod_gpx
-import utils as mod_utils
-import re as mod_re
+from . import gpx as mod_gpx
+from . import utils as mod_utils
 
 class XMLParser:
     """
-    Used when lxml is not available. Ises standard minidom.
+    Used when lxml is not available. Uses standard minidom.
     """
 
     dom = None
@@ -81,7 +83,7 @@ class XMLParser:
         return child_nodes[0].nodeValue
 
     def get_node_attribute(self, node, attribute):
-        if node.attributes.has_key(attribute):
+        if attribute in node.attributes.keys():
             return node.attributes[attribute].nodeValue
         return None
 
@@ -95,8 +97,14 @@ class LXMLParser:
     ns = None
 
     def __init__(self, xml):
-        self.xml = xml
-        self.dom = mod_etree.XML(xml)
+        if mod_utils.PYTHON_VERSION[0] == '3':
+            # In python 3 all strings are unicode and for some reason lxml 
+            # don't like unicode strings with XMLs declared as UTF-8:
+            self.xml = xml.encode('utf-8')
+        else:
+            self.xml = xml
+
+        self.dom = mod_etree.XML(self.xml)
         # get the namespace
         self.ns = self.dom.nsmap.get(None)
 
@@ -139,18 +147,17 @@ class LXMLParser:
     def get_node_attribute(self, node, attribute):
         return node.attrib.get(attribute)
 
-
 def parse_time(string):
     if not string:
         return None
     try:
         return mod_datetime.datetime.strptime(string, mod_gpx.DATE_FORMAT)
-    except Exception, e:
+    except Exception as e:
         if mod_re.match('^.*\.\d+Z$', string):
             string = mod_re.sub('\.\d+Z', 'Z', string)
         try:
             return mod_datetime.datetime.strptime(string, mod_gpx.DATE_FORMAT)
-        except Exception, e:
+        except Exception as e:
             mod_logging.error('Invalid timestemp %s' % string)
             return None
 
@@ -174,13 +181,8 @@ class GPXParser:
         self.xml_parser_type = parser
 
     def init(self, xml_or_file):
-        if hasattr(xml_or_file, 'read'):
-            self.xml = xml_or_file.read()
-        else:
-            if isinstance(xml_or_file, unicode):
-                self.xml = xml_or_file.encode('utf-8')
-            else:
-                self.xml = str(xml_or_file)
+        text = xml_or_file.read() if hasattr(xml_or_file, 'read') else xml_or_file
+        self.xml = mod_utils.make_str(text)
 
         self.valid = False
         self.error = None
@@ -203,17 +205,17 @@ class GPXParser:
                     self.xml_parser = LXMLParser(self.xml)
                 else:
                     self.xml_parser = XMLParser(self.xml)
-            if self.xml_parser_type == 'lxml':
+            elif self.xml_parser_type == 'lxml':
                 self.xml_parser = LXMLParser(self.xml)
             elif self.xml_parser_type == 'minidom':
                 self.xml_parser = XMLParser(self.xml)
             else:
-                raise mod_gpx.GPXException('Invalit parser type: %s' % self.xml_parser_type)
+                raise mod_gpx.GPXException('Invalid parser type: %s' % self.xml_parser_type)
 
             self.__parse_dom()
 
             return self.gpx
-        except Exception, e:
+        except Exception as e:
             mod_logging.debug('Error in:\n%s\n-----------\n' % self.xml)
             mod_logging.exception(e)
             self.error = str(e)
@@ -471,21 +473,21 @@ if __name__ == '__main__':
     gpx_xml = file.read()
     file.close()
 
-    parser = mod_gpx.GPXParser(gpx_xml)
+    parser = GPXParser(gpx_xml)
     gpx = parser.parse()
 
-    print gpx.to_xml()
+    print(gpx.to_xml())
 
     if parser.is_valid():
-        print 'TRACKS:'
+        print('TRACKS:')
         for track in gpx.tracks:
-            print 'name%s, 2d:%s, 3d:%s' % (track.name, track.length_2d(), track.length_3d())
-            print '\tTRACK SEGMENTS:'
+            print('name%s, 2d:%s, 3d:%s' % (track.name, track.length_2d(), track.length_3d()))
+            print('\tTRACK SEGMENTS:')
             for track_segment in track.segments:
-                print '\t2d:%s, 3d:%s' % (track_segment.length_2d(), track_segment.length_3d())
+                print('\t2d:%s, 3d:%s' % (track_segment.length_2d(), track_segment.length_3d()))
 
-        print 'ROUTES:'
+        print('ROUTES:')
         for route in gpx.routes:
-            print route.name
+            print(route.name)
     else:
-        print 'error: %s' % parser.get_error()
+        print('error: %s' % parser.get_error())
