@@ -14,9 +14,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import logging
+import sys as mod_sys
 import xml.sax.saxutils as mod_saxutils
 
+PYTHON_VERSION = mod_sys.version.split(' ')[0]
+
 def to_xml(tag, attributes={}, content=None, default=None, escape=False):
     result = '\n<%s' % tag
 
@@ -38,8 +40,7 @@ def to_xml(tag, attributes={}, content=None, default=None, escape=False):
 
     result += ''
 
-    if isinstance(result, unicode):
-        result = result.encode('utf-8')
+    result = make_str(result)
 	
     return result
 
@@ -63,7 +64,7 @@ def __hash(obj):
     if obj == None:
         return result
     elif isinstance(obj, dict):
-        raise Error('__hash_single_object for dict not yet implemented')
+        raise RuntimeError('__hash_single_object for dict not yet implemented')
     elif isinstance(obj, list) or isinstance(obj, tuple):
         return hash_list_or_tuple(obj)
 
@@ -84,3 +85,11 @@ def hash_object(obj, *attributes):
         result = result * 31 + __hash(getattr(obj, attribute))
 	
     return result
+
+
+def make_str(s):
+    """ Convert a str or unicode object into a str type. """
+    if PYTHON_VERSION[0] == '2':
+        if isinstance(s, unicode):
+            return s.encode("utf-8")
+    return str(s)
